@@ -2,13 +2,13 @@ from typing import Mapping, Sequence
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.translators import ALL_TRANSLATORS
-from weaverbird.pipeline import PipelineWithVariables
+from weaverbird.pipeline import Pipeline
 
 
 def translate_pipeline(
     *,
     sql_dialect: SQLDialect,
-    pipeline: PipelineWithVariables,
+    pipeline: Pipeline,
     tables_columns: Mapping[str, Sequence[str]],
     db_schema: str | None = None,
 ) -> str:
