@@ -2,14 +2,16 @@ from typing import TYPE_CHECKING
 
 from pypika import Field, functions
 from pypika.dialects import PostgreSQLQuery
+from pypika.terms import LiteralValue, Term
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
 from weaverbird.backends.pypika_translator.translators.base import (
+    DATE_INFO,
     DataTypeMapping,
     Self,
     SQLTranslator,
-    StepTable,
+    StepContext,
 )
 
 if TYPE_CHECKING:
@@ -27,23 +29,37 @@ class PostgreSQLTranslator(SQLTranslator):
         float="DOUBLE PRECISION",
         integer="INTEGER",
         text="TEXT",
+        datetime="TIMESTAMP",
+        timestamp="TIMESTAMP",
     )
     SUPPORT_ROW_NUMBER = True
     SUPPORT_SPLIT_PART = True
     FROM_DATE_OP = FromDateOp.TO_CHAR
     REGEXP_OP = RegexOp.SIMILAR_TO
-    TO_DATE_OP = ToDateOp.TO_DATE
+    TO_DATE_OP = ToDateOp.TO_TIMESTAMP
+    QUOTE_CHAR = '"'
+
+    @classmethod
+    def _add_date(
+        cls, *, date_column: Field, add_date_value: int, add_date_unit: DATE_INFO
+    ) -> Term:
+        return LiteralValue(f"{date_column.name} + INTERVAL '{add_date_value} {add_date_unit}'")
 
     def duration(
-        self: Self, *, step: "DurationStep", table: StepTable
-    ) -> tuple["QueryBuilder", StepTable]:
-        query: "QueryBuilder" = self.QUERY_CLS.from_(table.name).select(
-            *table.columns,
+        self: Self,
+        *,
+        builder: 'QueryBuilder',
+        prev_step_name: str,
+        columns: list[str],
+        step: "DurationStep",
+    ) -> StepContext:
+        query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
+            *columns,
             functions.Extract(
                 step.duration_in, Field(step.end_date_column) - Field(step.start_date_column)
             ).as_(step.new_column_name),
         )
-        return query, StepTable(columns=[*table.columns, step.new_column_name])
+        return StepContext(query, columns + [step.new_column_name])
 
 
 SQLTranslator.register(PostgreSQLTranslator)
